Get data available from SOTS moorings (limited to use in BOO atm, other variables could be added, select from pr_get_SOTSvariables)
Source:R/utils_sots.R
pr_get_SOTSMoorData.RdGet data available from SOTS moorings (limited to use in BOO atm, other variables could be added, select from pr_get_SOTSvariables)