Create interactive map showing IMOS plankton sampling coverage and progress

pr_plot_ProgressMap(dat, interactive = FALSE, labels = TRUE)

Arguments

dat

output from pr_get_ProgressMapData

interactive

Should the plot be interactive with leaflet?

labels

TRUE/FALSE Should labels be added to leaflet plot? Adding labels adds more information but slows down the rendering.

Value

a plot of IMOS progress

Examples

dat <- pr_get_ProgressMapData("NRS")
plot <- pr_plot_ProgressMap(dat)
#> Coordinate system already present.
#>  Adding new coordinate system, which will replace the existing one.